@@ -1,7 +1,7 @@
 /**
  * expand.h - expand a folder in the treeview
  *
- *	 Copyright 2012-2017 Andreas Rönnquist
+ *	 Copyright 2012-2023 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -22,11 +22,24 @@
 #ifndef __HEADER_EXPAND_
 #define __HEADER_EXPAND_
 
+
 /**
  *
  */
-void expand_tree(GtkTreeModel *tree_model, GtkTreeIter *start_iter);
-void start_expand_tree(GtkTreeModel *tree_model, GtkTreeIter *iter);
-gboolean get_expand_folder(gchar *folder_name);
+typedef struct FolderStatus {
+   gchar *folder_name;
+   gboolean folder_expanded;
+} FolderStatus;
+
+
+
+/**
+ *
+ */
+void expand_tree_with_expanded_list (GtkTreeModel *tree_model, GtkTreeIter *start_iter, GList *folder_status_list);
+
+void expand_tree (GtkTreeModel *tree_model, GtkTreeIter *start_iter);
+void start_expand_tree (GtkTreeModel *tree_model, GtkTreeIter *iter);
+gboolean get_expand_folder (gchar *folder_name);
 
 #endif /*__HEADER_EXPAND_*/
