@@ -1,7 +1,7 @@
 /**
  * gui_callbacks.c - GUI callback code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2023 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2025 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -213,26 +213,6 @@ static void fix_folders_step_through (GtkTreeView *tree_view, GtkTreeIter newite
 }
 
 
-gchar *remove_trailing_dot_folder (gchar *infolder)
-{
-   gchar *result = NULL;
-
-   if (g_str_has_suffix (infolder, "/.") == TRUE) {
-
-      int len = strlen (infolder);
-
-
-      result = g_strdup (infolder);
-
-      result[len - 2] = '\0';
-
-   } else {
-      result = g_strdup (infolder);
-   }
-
-   return result;
-}
-
 /**
  *
  */
@@ -253,14 +233,12 @@ void load_tree_at_iter (GtkTreeView *tree_view, GtkTreeIter *iter)
 
          gtk_tree_model_get (tree_model, iter, COLUMN_FILEPATH, &temp_folder_path, -1);
 
-         gchar *folder_path = g_path_get_dirname (temp_folder_path);
-
-         temp = folder_path;
-         folder_path = remove_trailing_dot_folder (temp);
+         temp = g_path_get_dirname (temp_folder_path);;
+         // gchar *folder_path = remove_trailing_dot_folder (temp);
          g_free (temp);
 
          // Load the wanted filter from the LUA config
-         GSList *filter_list = load_filter_from_lua (folder_path);
+         GSList *filter_list = load_filter_from_lua ();
 
          GSList *global_filter_list = prefs.hide_filter_global;
 
