@@ -1,7 +1,7 @@
 /**
  * gui_callbacks.h - GUI callback code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2018 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2023 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -24,16 +24,21 @@
 
 #define APP_SCITEPROJ_ERROR g_quark_from_static_string("APP_GUI_ERROR")
 
-void row_expand_or_collapse_cb(GtkTreeView *treeview, GtkTreeIter *arg1, GtkTreePath *arg2, gpointer user_data);
+void row_expand_or_collapse_cb (GtkTreeView *treeview, GtkTreeIter *arg1, GtkTreePath *arg2, gpointer user_data);
 
-void quit_menu_cb();
-void about_menu_cb();
-void creategroup_menu_cb();
+void quit_menu_cb ();
+void about_menu_cb ();
+void creategroup_menu_cb ();
 
-void popup_open_file_cb();
+void popup_open_file_cb ();
+
+void edit_properties_cb ();
+
+void refresh_folder (ClickedNode *inNode);
+void refresh_folder_with_iter (GtkTreeIter *iter);
+
+void create_new_file_cb ();
 
-void edit_properties_cb();
 
-void refresh_folder_cb();
 
 #endif /*__HEADER_GUI_CALLBACKS_*/
