@@ -216,7 +216,7 @@ gboolean add_tree_filelist (GtkTreeIter *parentIter, GSList *fileList, GError **
    // Reverse the list
    fileList = g_slist_reverse (fileList);
 
-   for (listIter = fileList; listIter != NULL; listIter = g_slist_next(listIter)) {
+   for (listIter = fileList; listIter != NULL; listIter = g_slist_next (listIter)) {
 
       gchar *absFilename = (gchar *) (listIter->data);
 
@@ -519,37 +519,6 @@ gboolean add_tree_file (GtkTreeIter *currentIter,
 
    gtk_tree_store_set (sTreeStore, &iter, COLUMN_FOLDER_CONTENT_LOADED, FALSE, -1);
 
-   /*
-   if (
-      (strcmp(fileExt,"cc")==0) ||
-      (strcmp(fileExt,"c++")==0) ||
-      (strcmp(fileExt,"c")==0) ||
-      (strcmp(fileExt,"cpp")==0)
-      ) {
-      gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, cpp_file_pixbuf, -1);
-
-   } else if (
-      (strcmp(fileExt,"hh")==0) ||
-      (strcmp(fileExt,"h++")==0) ||
-      (strcmp(fileExt,"h")==0) ||
-      (strcmp(fileExt,"hpp")==0)
-   ) {
-      gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, header_file_pixbuf, -1);
-
-   } else if (
-      (strcmp(fileExt,"lua")==0)
-   ) {
-      gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, lua_file_pixbuf, -1);
-
-   } else if (
-      (strcmp(fileExt,"java")==0)
-   ) {
-      gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, java_file_pixbuf, -1);
-   } else {
-      gtk_tree_store_set(sTreeStore, &iter, COLUMN_ICON, txt_file_pixbuf, -1);
-   }
-   */
-
    GdkPixbuf *icon_pixbuf = get_pixbuf_from_filename ((gchar*)(filepath), GTK_ICON_SIZE_MENU);
 
    gtk_tree_store_set (sTreeStore, &iter, COLUMN_ICON, icon_pixbuf, -1);
@@ -655,7 +624,7 @@ GtkTreeIter *find_element_with_path (GtkTreeIter *start_iter, gchar *path_to_fin
                gchar *cleaned_folder = NULL;
                cleaned_folder = g_strdup_printf ("%s/%s", get_project_directory (), clean_folder(nodeContents));
 
-               if (g_strcmp0(clean_folder (cleaned_folder), path_to_find) == 0) {
+               if (g_strcmp0 (clean_folder (cleaned_folder), path_to_find) == 0) {
 
                   GtkTreeIter *result_iter = gtk_tree_iter_copy (&new_iter);
 
@@ -1002,9 +971,9 @@ void print_node(GtkTreeIter *iter)
                        COLUMN_ITEMTYPE, &item_type,
                        COLUMN_FILEPATH, &node_contents,
                        COLUMN_FILENAME, &item_name,
-                       s-1);
+                       -1);
 
-   gchar *type_string;
+   gchar *type_string = NULL;
 
    switch (item_type) {
       case ITEMTYPE_GROUP:
@@ -1015,7 +984,8 @@ void print_node(GtkTreeIter *iter)
          break;
    };
 
-   printf ("Type: %s\n", type_string);
+   if (type_string != NULL)
+      printf ("Type: %s\n", type_string);
    printf ("Contents: '%s'\n", node_contents);
    printf ("File name: '%s'\n", item_name);
    printf ("-----\n");
